pub struct RateLimiterConfig {
pub bandwidth: Option<TokenBucket>,
pub ops: Option<TokenBucket>,
}Expand description
RateLimiterConfig : Defines an IO rate limiter with independent bytes/s and ops/s limits. Limits are defined by configuring each of the bandwidth and ops token buckets.
Fields
bandwidth: Option<TokenBucket>ops: Option<TokenBucket>Implementations
Sourceimpl RateLimiterConfig
impl RateLimiterConfig
Sourcepub fn new() -> RateLimiterConfig
pub fn new() -> RateLimiterConfig
Defines an IO rate limiter with independent bytes/s and ops/s limits. Limits are defined by configuring each of the bandwidth and ops token buckets.