TimeoutStrategy

Enum TimeoutStrategy 

pub enum TimeoutStrategy {
    Cancel,
    Ignore,
}
TimeoutStrategy : The strategy to apply when the migration timeout is reached. Cancel will abort the migration and keep the VM running on the source. Ignore will proceed with the migration regardless of the downtime requirement. The strategy to apply when the migration timeout is reached. Cancel will abort the migration and keep the VM running on the source. Ignore will proceed with the migration regardless of the downtime requirement.

Variants



Cancel



Ignore